@@ -36,8 +36,8 @@ def run(host="127.0.0.1", port=8080):
     utils.add_file_txt_count(config.count_day)
     print('_____running:____')
     print('please web browser', 'http://%s:%s' % (str(host), str(port)))
-    # uvicorn.run(app=app, host=host, port=port, log_level="error")
-    uvicorn.run(app=app, host=host, port=port)
+    uvicorn.run(app=app, host=host, port=port, log_level="error")
+    # uvicorn.run(app=app, host=host, port=port)
 
 
 if __name__ == '__main__':
